Writ of Acceptance Boston, Massachusetts June 24th 2007 3R+F 10 players D.J. Chagnon (Meej) -- 4vp in the final Deck Name: Darby Dance of the Seven Veils An adaptation of various Darby Dance decks, particularly John Newquist's 12/17/06 Razorbat: Atlanta winner (at least, that was the one that I saw a bunch of this tech in), modified to adapt to Boston's heavy-intercept typical metagame - one-stealth actions just rarely cut it, and 2 stealth sometimes isn't enough - by bolting in some OBF vampires into the crypt for Cloaks, Veils, and some blood-doll bloat. Also solves the problems of the classic Imbued vulnerability to Smiling Jack, Reins of Power, Ancient Influence, etc., at the cost of a little less reliability in the crypt, which bit me once badly in the 3rd round (all 4 vampires out of 5 crypt cards looked at).While I can't claim credit for much of the deck-manipulating innovation, Luc is just plain GOLD - the +3 hand-size action works great as an end-of- the-turn action to set up your hand for next turn. I think I'm going to switch out Jeffrey Mullins for a second Luc. Crypt (13 cards, min=12, max=20, avg=4) --------------------------------------- 2x Jennie "Cassie247" Orne 5 inn jud vis Visionary:4 2x Jack "Hannibal137" Harmon 4 def jud Defender:4 2x François "Warden" Loehr 3 def jud Judge:4 -- cheap! 2x Lubomira Hradok 3 OBF Nosferatu antitribu:5 1x Luc 5 OBF dem vic Malkavian antitribu:4 1x Travis "Traveler72" Miller 5 def mar Martyr:4 1x Jeffrey Mullins 4 OBF cel Gangrel antitribu:4 1x John "Cop90" O'Malley 4 jud ven Avenger:4 1x Marion "Teacher193" Perks 4 jud red Redeemer:4 Library (90 cards) Master (14) 4x Angel of Berlin 1x Barrens, The 2x Blood Doll 1x Church of Vindicated Faith, The 1x Dreams of the Sphinx 2x Memories of Mortality 2x Perfectionist -- weren't too useful - the Vamps didn't act too often. Maybe -1, +1 Blood Doll 1x Secure Haven Conviction (20) 5x React with Conviction 7x Second Sight 8x Strike with Conviction Action (4) 2x Psychic Veil -- nice, but tough to do unless I had 2 vamps out 2x Scrounging -- solid. Ally (3) 1x Carlton Van Wyk 1x Moise Kasavubu -- seems good, but never got him out to confirm - in past uses, he's just gotten blocked, but with the stealth I put him back in 1x Vagabond Mystic -- undecided; life was rarely an issue, except when a little healing wouldn't have mattered Equipment (16) 2x .44 Magnum -- could go away for Flash Grenades 1x Crusader Sword, The -- in retrospect, IR Goggles to go with this might be nice 1x Deer Rifle -- I expected transient maneuvers, and wasn't wrong 5x Flash Grenade -- could use more 1x Heart of Nizchetus 1x Ivory Bow 2x Laptop Computer 2x Leather Jacket -- because I own no NRA PAC 1x Orb of Ulain Power (9) 2x Champion 2x Rejuvenate -- see Vagabond Mystic - only so-so 5x Vigilance Action Modifier (14) 8x Cloak the Gathering 6x Veil the Legions Reaction (2) 2x Determine -- never used; took too much vsn out of the crypt, and rarely needed Combat (4) 4x Concealed Weapon Event (4) 1x Anthelios, The Red Star -- would be another Unmasking if I owned one 2x Edge Explosion 1x Unmasking, The